clear all

%%%
%   Script for comparing multiple simulation responses
%   This is tailored to four simulations, but can be adapted
%%%

%%% Style %%%
% general graphics, this will apply to any figure you open
% (groot is the default figure object).
set(groot, ...
'DefaultFigureColor', 'w', ...
'DefaultAxesLineWidth', 0.5, ...
'DefaultAxesXColor', 'k', ...
'DefaultAxesYColor', 'k', ...
'DefaultAxesFontUnits', 'points', ...
'DefaultAxesFontSize', 10, ...
'DefaultAxesFontName', 'Helvetica', ...
'DefaultLineLineWidth', 1.5, ...
'DefaultTextFontUnits', 'Points', ...
'DefaultTextFontSize', 10, ...
'DefaultTextFontName', 'Helvetica', ...
'DefaultAxesBox', 'off', ...
'DefaultAxesTickLength', [0.02 0.025]);
 
% set the tickdirs to go out - need this specific order
set(groot, 'DefaultAxesTickDir', 'out');
set(groot, 'DefaultAxesTickDirMode', 'manual');
%%%%%%%%%%%%%

%%% LOAD FOLDER %%%
fold = 'C:\Figures';    %Folder for storing plots
addpath(genpath('C:\marinlab'));    %Access file for Lanczos filter from SINTEF environment 
folder = 'C:\project_number\';
hlcc = '\HLCC_';
defrag = '_defrag.tdms';

%Specify simulation numbers for comparison
file1 = 'file1'; 
file2 = 'file2';
file3 = 'file3';
file4 = 'file4';

%Number of files for comparison
file_amount = 4;
data = 'data';

file_path1 = string(folder) + string(file1) + string(hlcc) + string(file1) + string(defrag);
file_path2 = string(folder) + string(file2) + string(hlcc) + string(file2) + string(defrag);
file_path3 = string(folder) + string(file3) + string(hlcc) + string(file3) + string(defrag);
file_path4 = string(folder) + string(file4) + string(hlcc) + string(file4) + string(defrag);

data1 = tdmsread(file_path1);
data2 = tdmsread(file_path2);
data3 = tdmsread(file_path3);
data4 = tdmsread(file_path4);

dataList = {data1, data2, data3, data4};
IO = cell(1,file_amount);

for i=1:file_amount
    dat = dataList{1,i};
    dat_size = size(dat);
    for j=1:dat_size(2)
    a = dat{1,j};
    b = size(a);
    if (b(2) == 7)
        input = a;
    elseif b(2)==13
        output = a;
    end
    end
    if (size(input,1) < size(output,1))
      output = output(1:end-1, :);
    elseif (size(output,1)<size(input,1))
        input = input(1:end-1, :);
    end
    c = [input output(:,2:end)];
    IO{1,i} = c;
    clear dat
end

for i=1:file_amount
    data = IO{1,i};
    data_size = size(data);
    len = data_size(1);
    hasOdd = any(mod(len,2)==1);
    if hasOdd == 1
        len=len-1;
    end
    start_ind = floor((len / 2) - 20000);
    end_ind = ceil((len / 2) + 20000);
    mid_list = start_ind:end_ind;
    mid_len=(length(mid_list));
    newData=table([zeros(mid_len,1)], [zeros(mid_len,1)], [zeros(mid_len,1)], [zeros(mid_len,1)] ...
        , [zeros(mid_len,1)], [zeros(mid_len,1)], [zeros(mid_len,1)], [zeros(mid_len,1)] ...
        ,[zeros(mid_len,1)], [zeros(mid_len,1)], [zeros(mid_len,1)], [zeros(mid_len,1)] ...
        , [zeros(mid_len,1)], [zeros(mid_len,1)], [zeros(mid_len,1)], [zeros(mid_len,1)] ...
        , [zeros(mid_len,1)], [zeros(mid_len,1)], [zeros(mid_len,1)] ...
        ,'VariableNames',data.Properties.VariableNames);
    for col=1:data_size(2)
        columnData = data(:,col);
        slicedColumn = columnData(start_ind:end_ind,data.Properties.VariableNames(col));
        newData(:,newData.Properties.VariableNames(col)) = slicedColumn(:, slicedColumn.Properties.VariableNames(1));
    end
    IO{1,i} = newData;
end

slice = (10000:38000); %from cirka 50 seconds to 200 - all plots coincides in this area 

%only care for surge to start with:
sim1_surge_in = IO{1,1}.("eta1_MoCap_m_ []")(slice);
sim2_surge_in = IO{1,2}.("eta1_MoCap_m_ []")(slice);
sim3_surge_in = IO{1,3}.("eta1_MoCap_m_ []")(slice);
sim4_surge_in = IO{1,4}.("eta1_MoCap_m_ []")(slice);

%average for comparison
eta_surge_average = (sim1_surge_in + sim2_surge_in + sim3_surge_in+ sim4_surge_in)/4;

%get yaw 
sim1_yaw_in = IO{1,1}.("eta6_MoCap_deg_ []")(slice);
sim2_yaw_in = IO{1,2}.("eta6_MoCap_deg_ []")(slice);
sim3_yaw_in = IO{1,3}.("eta6_MoCap_deg_ []")(slice);
sim4_yaw_in = IO{1,4}.("eta6_MoCap_deg_ []")(slice);

%average for comparison
eta_yaw_average = (sim1_yaw_in + sim2_yaw_in + sim3_yaw_in + sim4_yaw_in)/4;

sim1_etaLF_out = IO{1,1}.("eta1_LF_m_ []")(slice);
sim2_etaLF_out = IO{1,2}.("eta1_LF_m_ []")(slice);
sim3_etaLF_out = IO{1,3}.("eta1_LF_m_ []")(slice);
sim4_etaLF_out = IO{1,4}.("eta1_LF_m_ []")(slice);

sim1_etaWF_out = IO{1,1}.("eta1_WF_m_ []")(slice);
sim2_etaWF_out = IO{1,2}.("eta1_WF_m_ []")(slice);
sim3_etaWF_out = IO{1,3}.("eta1_WF_m_ []")(slice);
sim4_etaWF_out = IO{1,4}.("eta1_WF_m_ []")(slice);

sim1_nu_out = IO{1,1}.("nu1_LF_m_s_ []")(slice);
sim2_nu_out = IO{1,2}.("nu1_LF_m_s_ []")(slice);
sim3_nu_out = IO{1,3}.("nu1_LF_m_s_ []")(slice);
sim4_nu_out = IO{1,4}.("nu1_LF_m_s_ []")(slice);

sim1_bias = IO{1,1}.("bias1_N_ []")(slice);
sim2_bias = IO{1,2}.("bias1_N_ []")(slice);
sim3_bias = IO{1,3}.("bias1_N_ []")(slice);
sim4_bias = IO{1,4}.("bias1_N_ []")(slice);

sim1_tauref = IO{1,1}.("tau1_ref_N_ []")(slice);
sim2_tauref = IO{1,2}.("tau1_ref_N_ []")(slice);
sim3_tauref = IO{1,3}.("tau1_ref_N_ []")(slice);
sim4_tauref = IO{1,4}.("tau1_ref_N_ []")(slice);

tauref_average = (sim1_tauref + sim2_tauref + sim3_tauref + sim4_tauref)/4;
mean_val = mean(tauref_average(:));
mean_series = mean_val * ones(1, length(time));

%adjust time-vector for all simulations: (NB: time in UNIX-format)
time1 = IO{1,1}.("TIME [s]")(:);
%convert from unix
time = time1 - time1(1); 
time = time(slice);

%%% get filtered velocity %%%
scale = 40;
T = time(end);
cutOffPer = 30/sqrt(scale); %the wave period which is cut-off
dt = mean(gradient(time))
stdTime = std(gradient(time))
f1 = filt.Lanczos(2*pi/cutOffPer,3,'lo',dt); %lowpass filter using FFT (faster)


Nfilt = f1*eta_surge_average;  %XPOS
Efilt = zeros(length(eta_sway_average),1); %YPOS=0 for this application
psiFilt = f1*eta_yaw_average; %ZPOS

%gradient: partial derivatives
velGlobFilt = [gradient(Nfilt)/dt gradient(Efilt)/dt gradient(psiFilt)/dt];
velLocFilt = zeros(length(time),3);
for idx=1:length(time)
        %rotate to body-frame
    velLocFilt(idx,:) = (Rzyx_(0,0,eta_yaw_average(idx)*pi/180)*velGlobFilt(idx,:).').';
end

%compare the input 
figure('Renderer', 'painters', 'Position', [50 50 900 600])
hold on
plot(time,sim1_bias)
plot(time,sim2_bias)
plot(time, sim3_bias)
plot(time, sim4_bias)
plot(time, tauref_average,'--')
plot(time, -mean_series, 'color', 'k', LineStyle='--')
hold off
xlabel('Time [s]')
ylabel('Force [N]')
title('Bias vs. \tau_{ref} [surge]')
legend('$$\hat{b}_1$$','$$\hat{b}_2$$','$$\hat{b}_3$$', '$$\hat{b}_4$$', '$$\tau_{average}$$','bias reference','Interpreter','Latex')
ax = gcf;
file = fullfile(fold, 'bias.jpg');
exportgraphics(ax,file)


%%% plot %%%

%compare the input 
figure('Renderer', 'painters', 'Position', [50 50 900 600])
hold on
plot(time,sim1_surge_in)
plot(time,sim2_surge_in)
plot(time, sim3_surge_in)
plot(time, sim4_surge_in)
plot(time, eta_surge_average,'--')
hold off
xlabel('Time [s]')
ylabel('Motions [m]')
title('\eta_{in} [surge]')
legend('\eta^1_{in}','\eta^2_{in}','\eta^3_{in}', '\eta^4_{in}', '\eta_{average}')
ax = gcf;
file = fullfile(fold, 'eta_MoCap.jpg');
exportgraphics(ax,file)


%compare the output 
figure('Renderer', 'painters', 'Position', [50 50 900 600])
hold on
plot(time,sim1_etaLF_out)
plot(time,sim2_etaLF_out)
plot(time, sim3_etaLF_out)
plot(time, sim4_etaLF_out)
plot(time, eta_surge_average,'--')
hold off
xlabel('Time [s]')
ylabel('Motions [m]')
title('\eta_{LF} [surge]')
legend('\eta^1_{LF}','\eta^2_{LF}','\eta^3_{LF}','\eta^4_{LF}', '\eta_{average}')
ax = gcf;
file = fullfile(fold, 'eta_LF.jpg');
exportgraphics(ax,file)

%compare the output 
figure('Renderer', 'painters', 'Position', [50 50 900 600])
hold on
plot(time,sim1_etaLF_out)
plot(time,sim2_etaLF_out)
plot(time, sim3_etaLF_out)
plot(time, sim4_etaLF_out)
plot(time, eta_surge_average,'--')
hold off
xlim([50 100])
xlabel('Time [s]')
ylabel('Motions [m]')
title('Sliced \eta_{LF} [surge]')
legend('\eta^1_{LF}','\eta^2_{LF}','\eta^3_{LF}','\eta^4_{LF}', '\eta_{average}')
ax = gcf;
file = fullfile(fold, 'eta_LF_sliced.jpg');
exportgraphics(ax,file)


%compare the output 
figure('Renderer', 'painters', 'Position', [50 50 900 600])
hold on
plot(time,sim1_etaWF_out)
plot(time,sim2_etaWF_out)
plot(time, sim3_etaWF_out)
plot(time, sim4_etaWF_out)
hold off
xlabel('Time [s]')
ylabel('Motions [m]')
title('\eta_{WF} [surge]')
legend('\eta^1_{WF}','\eta^2_{WF}','\eta^3_{WF}','\eta^4_{WF}')
ax = gcf;
file = fullfile(fold, 'eta_WF.jpg');
exportgraphics(ax,file)


%Nu
figure('Renderer', 'painters', 'Position', [50 50 900 600])
hold on
plot(time,sim1_nu_out)
plot(time,sim2_nu_out)
plot(time,sim3_nu_out)
plot(time,sim4_nu_out)
hold off
xlabel('Time [s]')
ylabel('Velocity [m/s]')
title('\nu [surge]')
legend('\nu_1', '\nu_2', '\nu_3','\nu_4')
ax = gcf;
file = fullfile(fold, 'nu.jpg');
exportgraphics(ax,file)

LFmeans = [mean(sim1_etaLF_out) mean(sim2_etaLF_out) mean(sim3_etaLF_out) mean(sim4_etaLF_out)]
nuMeans = [mean(sim1_nu_out) mean(sim2_nu_out) mean(sim3_nu_out) mean(sim4_nu_out)]
LFstds = [std(sim1_etaLF_out) std(sim2_etaLF_out) std(sim3_etaLF_out) std(sim4_etaLF_out)]

