package no.marintek.generic.control;


/**
 * Interface for Generic External Control System
 */
public interface IController {

	/**
	 * Method called once before simulation starts
	 * 
	 * @param dt
	 *            Time step
	 * @param parameters
	 *            Container for controller parameters
	 */
	void init(double dt, Parameters parameters);

	/**
	 * Method called on each time step
	 * 
	 * @param t
	 *            Current simulation time
	 * @param measurements
	 *            Container with measurements from simulation
	 * @param feedback
	 *            Container for feedback to simulation
	 */
	void step(double t, Signal measurements, Signal feedback);

	/**
	 * Method called once after simulation is done
	 */
	void finish();

}
