package no.marintek.generic.control;

import java.util.Set;

/**
 * Container of parameters sent from the numerical simulation to the external control system. All parameters have a name and an associated value which
 * can be either an integer, a real or a string. Names must be unique within its data type.
 */
public interface Parameters {

	/**
	 * @param name
	 *            Name of parameter
	 * @return Integer parameter with given name
	 */
	public int getInt(String name);

	/**
	 * @param name
	 *            Name of parameter
	 * @return Float parameter with given name
	 */
	public double getReal(String name);

	/**
	 * @param name
	 *            Name of parameter
	 * @return String parameter with given name
	 */
	public String getString(String name);

	/**
	 * @return A {@link Set} with names of all integer parameters
	 */
	public Set<String> getIntNames();

	/**
	 * @return A {@link Set} with names of all real parameters
	 */
	public Set<String> getRealNames();

	/**
	 * @return A {@link Set} with names of all string parameters
	 */
	public Set<String> getStringNames();

}